@@ -364,12 +364,11 @@ class FieldsConverterOneWay:
             self.cred["port"],
             self.cred["database"],
         )
-
-        if "connect_args" in self.sql_credentials[self.db]:
-            connect_args = self.sql_credentials[self.db]["connect_args"]
-        else:
-            connect_args = {}
-        self.engine = create_engine(uri_sql_alchemy, connect_args=connect_args)
+        additional_args = {}
+        for key in self.sql_credentials[self.db]:
+            if key not in ["database", "schema", "user", "host", "password", "port"]:
+                additional_args[key] = self.sql_credentials[self.db][key]
+        self.engine = create_engine(uri_sql_alchemy, **additional_args)
         self.conn = self.engine.connect()
         self.log("connecting to {} successfull".format(self.db))
         self.quote_char = quotes_dict[self.db]
@@ -560,21 +559,18 @@ class FieldsConverter:
             self.cred_to["database"],
         )
         self.quote_char = quotes_dict[self.to_db]
-        if "connect_args" in self.sql_credentials[self.from_db]:
-            connect_args = self.sql_credentials[self.from_db]["connect_args"]
-        else:
-            connect_args = {}
-        self.engine_from = create_engine(
-            uri_sql_alchemy_from, connect_args=connect_args
-        )
+        additional_args = {}
+        for key in self.sql_credentials[self.from_db]:
+            if key not in ["database", "schema", "user", "host", "password", "port"]:
+                additional_args[key] = self.sql_credentials[self.from_db][key]
+        self.engine_from = create_engine(uri_sql_alchemy_from, **additional_args)
         self.conn_from = self.engine_from.connect()
         self.log("connecting to {} successfull".format(self.from_db))
-
-        if "connect_args" in self.sql_credentials[self.to_db]:
-            connect_args = self.sql_credentials[self.to_db]["connect_args"]
-        else:
-            connect_args = {}
-        self.engine_to = create_engine(uri_sql_alchemy_to, connect_args=connect_args)
+        additional_args = {}
+        for key in self.sql_credentials[self.to_db]:
+            if key not in ["database", "schema", "user", "host", "password", "port"]:
+                additional_args[key] = self.sql_credentials[self.to_db][key]
+        self.engine_to = create_engine(uri_sql_alchemy_to, **additional_args)
         self.conn_to = self.engine_to.connect()
         self.log("connecting to {} successfull".format(self.to_db))
         self.init_meta(tables=self.tables)
@@ -676,18 +672,18 @@ class FieldsConverter:
                     fields[date_field] += " not null"
         elif self.to_db == "exasol":
             cur_schema = self.exasol_schema
-        txt = "CREATE TABLE IF NOT EXISTS {schema}.{table} (".format(
+        txt = "CREATE TABLE IF NOT EXISTS {schema}.{table}\n(\n".format(
             schema=cur_schema, table=table_name
         )
 
-        txt += ",".join(
+        txt += ",\n".join(
             [
-                self.quote_char + field + self.quote_char + " " + str(fields[field])
+                "    " + self.quote_char + field + self.quote_char + " " + str(fields[field])
                 for field in fields
                 if field not in excluded_fields
             ]
         )
-        txt += ")"
+        txt += "\n)"
 
         return txt + " " + add_part
 
